<?php
/**
 * Responso AJAX controller class sending data from forms.
 *
 * @package Responso
 */

namespace Responso;

/**
 * @package PayPo
 */
class Responso_Ajax extends Responso_Connect {

	/**
	 * Init Responso Ajax
	 *
	 * @param object $plugin_info .
	 */
	public function __construct() {

        $this->api_key = get_option('api_key');
        $this->source = 'woo_commerce';

        add_action('wp_ajax_send_forms', [$this, 'send_forms']);
        add_action('wp_ajax_nopriv_send_forms', [$this, 'send_forms']);
    }


    public function send_forms() {

        if (!wp_verify_nonce($_POST['nonce'], 'responso_secure_nonce')) {

            echo 'Sorry, ajax token is incorrect.';
            wp_die();
        }

        if($_POST['type'] == 'contact_form') {
           
            $request_body = [
                'email' =>  $_POST['responso_email'],
                'phone' => $_POST['responso_phone'],
                'message' => $_POST['responso_msg'],
                'details' => [
                    'name' => $_POST['responso_full_name'],
                    'subject' => $_POST['responso_subject'],
                    'type' => $_POST['type'],
                ],
                'source' => $this->source,
            ];

            if(!empty($_POST['responso_order_id']))
                $request_body['details']['order_id'] = $_POST['responso_order_id'];

            $args = array(
                'headers' => array(
                    'Content-Type' => 'application/json',
                    'apiKey' => $this->api_key,
                ),
                'body' => wp_json_encode($request_body),
            );
            $response = $this->remote_post('/ticket', $args);

            if(!empty($response))
                echo __('Sorry, your message has not been sent. Error code: ', 'responso').$response['code'];
            else
                echo __('Thank you for submitting your contact inquiry. We will reply as soon as possible.', 'responso');
        }

        if($_POST['type'] == 'product_question') {

            $request_body = [
                'email' =>  $_POST['responso_email'],
                'phone' => $_POST['responso_phone'],
                'message' => $_POST['responso_msg'],
                'details' => [
                    'name' => $_POST['responso_full_name'],
                    'product_id' => $_POST['product_id'],
                    'type' => $_POST['type'],
                ],
                'source' => $this->source,
            ];

            $args = array(
                'headers' => array(
                    'Content-Type' => 'application/json',
                    'apiKey' => $this->api_key,
                ),
                'body' => wp_json_encode($request_body),
            );
            $response = $this->remote_post('/ticket', $args);
            
            if(!empty($response))
                echo __('Sorry, your message has not been sent. Error code: ', 'responso').$response['code'];
            else
                echo __('Thank you for submitting your product inquiry. We will reply as soon as possible.', 'responso');
        }

        wp_die();
    }
}