<?php
/**
 * Responso forms class.
 *
 * @package Responso
 */

namespace Responso;

/**
 * @package PayPo
 */
class Responso_Forms {

	/**
	 * Init Responso forms
	 *
	 * @param object $plugin_info .
	 */
	public function __construct($plugin_info) {

		$this->plugin_info = $plugin_info;

		$this->form_header = get_option('form_header');
		$this->form_text = get_option('form_text');
		$this->form_subjects = get_option('form_subjects');
		$this->product_form_button_text = get_option('product_form_button_text');
		$this->product_form_text = get_option('product_form_text');
		$this->form_acceptance_text = get_option('form_acceptance_text');
		$this->form_footer_img = $this->plugin_info->plugin_url.'/assets/images/logo.png';
		$this->form_footer_url = 'https://responso.com/pl/?utm_campaign=Woocommerce-wtyczka&utm_medium=wtyczka&utm_source=woocommerce&utm_content=power-by-str';

        $this->register_shortcodes();
        $this->forms_hooks();
    }


	public function user_data_for_autofill_form_fields() {

		$user_data_form = ['full_name' => '', 'email' => '', 'phone' => ''];
		if(is_user_logged_in()) {

			global $current_user;
			$user_data_form['full_name'] = $current_user->user_firstname;
			if($current_user->user_lastname != '')
				$user_data_form['full_name'] = $current_user->user_firstname.' '.$current_user->user_lastname;
			
			$user_data_form['email'] = $current_user->user_email;
			$user_data_form['phone'] = get_user_meta($current_user->ID, 'billing_phone', true);
		}

		return $user_data_form;
	}


    public function contact_form() {

		$button_html = '';

		$header_html = '';
		if(!empty($this->form_header))
			$header_html .= '<h3 class="responso_form__header">'.$this->form_header.'</h3>';

		$text_html = '';
		if(!empty($this->form_text))
			$text_html .= '<p class="responso_form__text">'.$this->form_text.'</p>';

		$subjects_html = '';
		$form_subjects = explode(PHP_EOL, $this->form_subjects);
		if(!empty($form_subjects)) {

			$subjects_html .= '
			<div class="responso_form__col responso_form__col--fullwidth">
				<label for="responso_subject">'.__('Message Subject', 'responso').'</label>
				<select name="responso_subject" id="responso_subject" class="responso_form__select">';

			foreach($form_subjects as $form_subject)
				$subjects_html .= '<option value="'.$form_subject.'">'.$form_subject.'</option>';

			$subjects_html .= '
				</select>
			</div>';
		}

		$order_id_input = '<div class="responso_form__col"><input type="text" name="responso_order_id" id="responso_order_id" class="responso_form__input" placeholder="'.__('Order Number', 'responso').'"></div>';
		$product_id_input = '';

		$nonce = wp_create_nonce('responso_secure_nonce');

		$form_html = $this->generate_form_html('contact_form', $header_html, $text_html, $nonce, $subjects_html, $button_html, $order_id_input, $product_id_input, $this->user_data_for_autofill_form_fields());
        return $form_html;
    }


	public function product_form() {

		$button_html = '<button class="responso_product_form__button">'.$this->product_form_button_text.'</button>';

		$header_html = '';
		$text_html = '';

		if(!empty($this->product_form_text))
			$text_html .= '<p class="responso_form__text">'.$this->product_form_text.'</p>';

		$subjects_html = '';

		$order_id_input = '';
		$product_id_input = '<input type="hidden" name="product_id" value="'.get_the_ID().'" class="responso_form__hidden">';

		$nonce = wp_create_nonce('responso_secure_nonce');

		$form_html = $this->generate_form_html('product_question', $header_html, $text_html, $nonce, $subjects_html, $button_html, $order_id_input, $product_id_input, $this->user_data_for_autofill_form_fields());
    	echo $form_html;
	}


	public function generate_form_html($type, $header_html, $text_html, $nonce, $subjects_html, $button_html, $order_id_input, $product_id_input, $user_data) {

		$form_box_extra_class = '';
		$phone_col_extra_class = '';
		if($type == 'product_question'){
			$form_box_extra_class = ' responso_form__box--hidden';
			$phone_col_extra_class = ' responso_form__col--fullwidth';
		}

		$acceptance_html = '';
		if($this->form_acceptance_text != '')
			$acceptance_html = '<div class="responso_form__col responso_form__col--fullwidth">
			<input type="checkbox" name="form_acceptance" id="form_acceptance" required> '.$this->form_acceptance_text.'
		</div>';

		$form_html = '
		'.$button_html.'
        <div class="responso_form__box'.$form_box_extra_class.'">
			'.$header_html.'
			'.$text_html.'
			<div class="responso_form__info"></div>
			<form method="post" action="" class="responso_form">
				<input type="hidden" name="action" value="send_forms" class="responso_form__hidden">
				<input type="hidden" name="type" value="'.$type.'" class="responso_form__hidden">
				<input type="hidden" name="nonce" value="'.$nonce.'" class="responso_form__hidden">
				'.$product_id_input.'
				<div class="responso_form__col"><input type="text" name="responso_full_name" id="responso_full_name" class="responso_form__input" placeholder="'.__('Full Name', 'responso').'" value="'.$user_data['full_name'].'" required></div>
				<div class="responso_form__col"><input type="email" name="responso_email" id="responso_email" class="responso_form__input" placeholder="'.__('E-mail', 'responso').'" value="'.$user_data['email'].'" required></div>
				<div class="responso_form__col'.$phone_col_extra_class.'"><input type="tel" name="responso_phone" id="responso_phone" class="responso_form__input" placeholder="'.__('Phone', 'responso').'"  value="'.$user_data['phone'].'"></div>
				'.$order_id_input.'
				'.$subjects_html.'
				<div class="responso_form__col responso_form__col--fullwidth"><textarea name="responso_msg" rows="4" id="responso_msg" class="responso_form__textarea" placeholder="'.__('Message', 'responso').'" required></textarea></div>
				'.$acceptance_html.'
				<div class="responso_form__col">
					<button type="submit" id="responso_form_submit" class="responso_form__submit">'.__('Send', 'responso').'</button>
					<div class="responso_form__footer">
						<span class="form_text">'.__('Powered by', 'responso').'</span>
						<a href="'.$this->form_footer_url.'" target="_blank" class="footer_url"><img src="'.$this->form_footer_img.'" class="footer_img"></a>
					</div>
				</div>
			</form>
        </div>';

		return $form_html;
    }
	

    /**
	 * Register forms shortcodes
	 */
	public function register_shortcodes() {

        add_shortcode('responso_contact_form', [$this, 'contact_form']);
    }

	public function forms_script_enqueuer() {

		wp_register_script('responso_forms', $this->plugin_info->plugin_url.'assets/js/send_forms.js', ['jquery']);
		wp_localize_script('responso_forms', 'responsoAjax', ['ajaxurl' => admin_url('admin-ajax.php')]);
		wp_enqueue_script('responso_forms');
	}


    /**
	 * Init actions required by this forms
	 */
	public function forms_hooks() {

		add_action('woocommerce_after_add_to_cart_form', [$this, 'product_form']);
		add_action('init', [$this, 'forms_script_enqueuer']);
    }
}